Learn R Programming

stattleshipR (version 0.0.5)

hockey_games: Retrieve the available hockey games for a given team

Description

A function to retrieve all of the available hockey games for a specified team.

Usage

hockey_games(league = "nhl", team_id = "nhl-bos", verbose = TRUE)

Arguments

league
character. The hockey league to retrieve. Currently only the NHL is supported, and is the default.
team_id
character. The team id, can be in the form of the slug "nhl-bos". Default is the Boston Bruins, nhl-bos.
verbose
logical. TRUE will print messages to the console. Default is TRUE.

Value

a dataframe of the hockey teams for the specified league.

Examples

Run this code
## Not run: 
# set_token("insert-your-token-here")
# results <- hockey_games(league="nhl", team_id="nhl-bos")
# ## End(Not run)

Run the code above in your browser using DataLab