Learn R Programming

stattleshipR (version 0.0.5)

hockey_injuries: Retrieve hockey injuries for a league

Description

A function to retrieve all of the injuries in hockey, for a given team.

Usage

hockey_injuries(league = "nhl", team_id = "", verbose = TRUE)

Arguments

league
character. The hockey league to retrieve. Currently only the NHL is supported, and is the default.
team_id
character. Optional. The team id, can be in the form of the slug "nhl-bos". Default is all teams (empty character).
verbose
logical. TRUE will print messages to the console. Default is TRUE.

Value

a dataframe of the hockey injuries for the specified league, and optionally, for a given team.

Examples

Run this code
## Not run: 
# set_token("insert-your-token-here")
# results_bos <- hockey_injuries(league="nhl", team_id="nhl-bos") ## bruins injuries
# results_all <- hockey_injuries(league="nhl") ## all injuries
# ## End(Not run)

Run the code above in your browser using DataLab