Learn R Programming

stattleshipR (version 0.0.5)

hockey_teams: Retrieve the available hockey teams

Description

A function to retrieve all of the available hockey teams for a specified league.

Usage

hockey_teams(league = "nhl", verbose = TRUE)

Arguments

league
character. The hockey league to retrieve. Currently only the NHL is supported, and is the default.
verbose
logical. TRUE will print messages to the console. Default is TRUE.

Value

a dataframe of the hockey teams for the specified league.

Examples

Run this code
## Not run: 
# set_token("insert-your-token-here")
# results <- hockey_teams(league="nhl")
# ## End(Not run)

Run the code above in your browser using DataLab